Module constructors

Module constructors 

This file was generated by eure-gen. Do not edit manually.

Modules

terminals

Structs

ArrayBeginConstructor
ArrayBeginConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayBeginNode
Branded type for ArrayBegin non-terminal
ArrayConstructor
ArrayConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayElementsConstructor
ArrayElementsConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayElementsNode
Branded type for ArrayElements non-terminal
ArrayElementsOptConstructor
ArrayElementsOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayElementsOptNode
Branded type for ArrayElementsOpt non-terminal
ArrayElementsTailConstructor
ArrayElementsTailConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayElementsTailNode
Branded type for ArrayElementsTail non-terminal
ArrayElementsTailOptConstructor
ArrayElementsTailOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayElementsTailOptNode
Branded type for ArrayElementsTailOpt non-terminal
ArrayEndConstructor
ArrayEndConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayEndNode
Branded type for ArrayEnd non-terminal
ArrayMarkerConstructor
ArrayMarkerConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayMarkerNode
Branded type for ArrayMarker non-terminal
ArrayMarkerOptConstructor
ArrayMarkerOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayMarkerOptNode
Branded type for ArrayMarkerOpt non-terminal
ArrayNode
Branded type for Array non-terminal
ArrayOptConstructor
ArrayOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ArrayOptNode
Branded type for ArrayOpt non-terminal
AtConstructor
AtConstructorBuilder
Use builder syntax to set the inputs and finish with build().
AtNode
Branded type for At non-terminal
AtToken
Branded type for At terminal
Backtick2Constructor
Backtick2ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
Backtick2Node
Branded type for Backtick2 non-terminal
Backtick2Token
Branded type for Backtick2 terminal
Backtick3Constructor
Backtick3ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
Backtick3Node
Branded type for Backtick3 non-terminal
Backtick3Token
Branded type for Backtick3 terminal
Backtick4Constructor
Backtick4ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
Backtick4Node
Branded type for Backtick4 non-terminal
Backtick4Token
Branded type for Backtick4 terminal
Backtick5Constructor
Backtick5ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
Backtick5Node
Branded type for Backtick5 non-terminal
Backtick5Token
Branded type for Backtick5 terminal
BacktickDelimConstructor
BacktickDelimConstructorBuilder
Use builder syntax to set the inputs and finish with build().
BacktickDelimNode
Branded type for BacktickDelim non-terminal
BacktickDelimToken
Branded type for BacktickDelim terminal
BeginConstructor
BeginConstructorBuilder
Use builder syntax to set the inputs and finish with build().
BeginNode
Branded type for Begin non-terminal
BindConstructor
BindConstructorBuilder
Use builder syntax to set the inputs and finish with build().
BindNode
Branded type for Bind non-terminal
BindToken
Branded type for Bind terminal
BindingConstructor
BindingConstructorBuilder
Use builder syntax to set the inputs and finish with build().
BindingNode
Branded type for Binding non-terminal
BindingRhsNode
Branded type for BindingRhs non-terminal
BooleanNode
Branded type for Boolean non-terminal
CodeBlock3Constructor
CodeBlock3ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlock3ListConstructor
CodeBlock3ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlock3ListGroupNode
Branded type for CodeBlock3ListGroup non-terminal
CodeBlock3ListNode
Branded type for CodeBlock3List non-terminal
CodeBlock3Node
Branded type for CodeBlock3 non-terminal
CodeBlock4Constructor
CodeBlock4ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlock4ListConstructor
CodeBlock4ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlock4ListGroupNode
Branded type for CodeBlock4ListGroup non-terminal
CodeBlock4ListNode
Branded type for CodeBlock4List non-terminal
CodeBlock4Node
Branded type for CodeBlock4 non-terminal
CodeBlock5Constructor
CodeBlock5ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlock5ListConstructor
CodeBlock5ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlock5ListGroupNode
Branded type for CodeBlock5ListGroup non-terminal
CodeBlock5ListNode
Branded type for CodeBlock5List non-terminal
CodeBlock5Node
Branded type for CodeBlock5 non-terminal
CodeBlock6Constructor
CodeBlock6ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlock6ListConstructor
CodeBlock6ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlock6ListGroupNode
Branded type for CodeBlock6ListGroup non-terminal
CodeBlock6ListNode
Branded type for CodeBlock6List non-terminal
CodeBlock6Node
Branded type for CodeBlock6 non-terminal
CodeBlockEnd3Constructor
CodeBlockEnd3ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlockEnd3Node
Branded type for CodeBlockEnd3 non-terminal
CodeBlockEnd3Token
Branded type for CodeBlockEnd3 terminal
CodeBlockEnd4Constructor
CodeBlockEnd4ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlockEnd4Node
Branded type for CodeBlockEnd4 non-terminal
CodeBlockEnd4Token
Branded type for CodeBlockEnd4 terminal
CodeBlockEnd5Constructor
CodeBlockEnd5ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlockEnd5Node
Branded type for CodeBlockEnd5 non-terminal
CodeBlockEnd5Token
Branded type for CodeBlockEnd5 terminal
CodeBlockEnd6Constructor
CodeBlockEnd6ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlockEnd6Node
Branded type for CodeBlockEnd6 non-terminal
CodeBlockEnd6Token
Branded type for CodeBlockEnd6 terminal
CodeBlockNode
Branded type for CodeBlock non-terminal
CodeBlockStart3Constructor
CodeBlockStart3ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlockStart3Node
Branded type for CodeBlockStart3 non-terminal
CodeBlockStart3Token
Branded type for CodeBlockStart3 terminal
CodeBlockStart4Constructor
CodeBlockStart4ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlockStart4Node
Branded type for CodeBlockStart4 non-terminal
CodeBlockStart4Token
Branded type for CodeBlockStart4 terminal
CodeBlockStart5Constructor
CodeBlockStart5ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlockStart5Node
Branded type for CodeBlockStart5 non-terminal
CodeBlockStart5Token
Branded type for CodeBlockStart5 terminal
CodeBlockStart6Constructor
CodeBlockStart6ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CodeBlockStart6Node
Branded type for CodeBlockStart6 non-terminal
CodeBlockStart6Token
Branded type for CodeBlockStart6 terminal
CommaConstructor
CommaConstructorBuilder
Use builder syntax to set the inputs and finish with build().
CommaNode
Branded type for Comma non-terminal
CommaToken
Branded type for Comma terminal
ContinueConstructor
ContinueConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ContinueNode
Branded type for Continue non-terminal
DelimCode1Constructor
DelimCode1ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCode1ListConstructor
DelimCode1ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCode1ListGroupNode
Branded type for DelimCode1ListGroup non-terminal
DelimCode1ListNode
Branded type for DelimCode1List non-terminal
DelimCode1Node
Branded type for DelimCode1 non-terminal
DelimCode2Constructor
DelimCode2ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCode2ListConstructor
DelimCode2ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCode2ListGroupNode
Branded type for DelimCode2ListGroup non-terminal
DelimCode2ListNode
Branded type for DelimCode2List non-terminal
DelimCode2Node
Branded type for DelimCode2 non-terminal
DelimCode3Constructor
DelimCode3ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCode3ListConstructor
DelimCode3ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCode3ListGroupNode
Branded type for DelimCode3ListGroup non-terminal
DelimCode3ListNode
Branded type for DelimCode3List non-terminal
DelimCode3Node
Branded type for DelimCode3 non-terminal
DelimCodeEnd1Constructor
DelimCodeEnd1ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCodeEnd1Node
Branded type for DelimCodeEnd1 non-terminal
DelimCodeEnd1Token
Branded type for DelimCodeEnd1 terminal
DelimCodeEnd2Constructor
DelimCodeEnd2ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCodeEnd2Node
Branded type for DelimCodeEnd2 non-terminal
DelimCodeEnd2Token
Branded type for DelimCodeEnd2 terminal
DelimCodeEnd3Constructor
DelimCodeEnd3ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCodeEnd3Node
Branded type for DelimCodeEnd3 non-terminal
DelimCodeEnd3Token
Branded type for DelimCodeEnd3 terminal
DelimCodeNode
Branded type for DelimCode non-terminal
DelimCodeStart1Constructor
DelimCodeStart1ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCodeStart1Node
Branded type for DelimCodeStart1 non-terminal
DelimCodeStart1Token
Branded type for DelimCodeStart1 terminal
DelimCodeStart2Constructor
DelimCodeStart2ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCodeStart2Node
Branded type for DelimCodeStart2 non-terminal
DelimCodeStart2Token
Branded type for DelimCodeStart2 terminal
DelimCodeStart3Constructor
DelimCodeStart3ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DelimCodeStart3Node
Branded type for DelimCodeStart3 non-terminal
DelimCodeStart3Token
Branded type for DelimCodeStart3 terminal
DollarToken
Branded type for Dollar terminal
DotConstructor
DotConstructorBuilder
Use builder syntax to set the inputs and finish with build().
DotNode
Branded type for Dot non-terminal
DotToken
Branded type for Dot terminal
EndConstructor
EndConstructorBuilder
Use builder syntax to set the inputs and finish with build().
EndNode
Branded type for End non-terminal
EscToken
Branded type for Esc terminal
EureBindingsConstructor
EureBindingsConstructorBuilder
Use builder syntax to set the inputs and finish with build().
EureBindingsNode
Branded type for EureBindings non-terminal
EureConstructor
EureConstructorBuilder
Use builder syntax to set the inputs and finish with build().
EureNode
Branded type for Eure non-terminal
EureOptConstructor
EureOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
EureOptNode
Branded type for EureOpt non-terminal
EureSectionsConstructor
EureSectionsConstructorBuilder
Use builder syntax to set the inputs and finish with build().
EureSectionsNode
Branded type for EureSections non-terminal
ExtConstructor
ExtConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ExtNode
Branded type for Ext non-terminal
ExtensionNameSpaceConstructor
ExtensionNameSpaceConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ExtensionNameSpaceNode
Branded type for ExtensionNameSpace non-terminal
FalseConstructor
FalseConstructorBuilder
Use builder syntax to set the inputs and finish with build().
FalseNode
Branded type for False non-terminal
FalseToken
Branded type for False terminal
FloatConstructor
FloatConstructorBuilder
Use builder syntax to set the inputs and finish with build().
FloatNode
Branded type for Float non-terminal
FloatToken
Branded type for Float terminal
GrammarNewlineConstructor
GrammarNewlineConstructorBuilder
Use builder syntax to set the inputs and finish with build().
GrammarNewlineNode
Branded type for GrammarNewline non-terminal
GrammarNewlineToken
Branded type for GrammarNewline terminal
HashToken
Branded type for Hash terminal
HoleConstructor
HoleConstructorBuilder
Use builder syntax to set the inputs and finish with build().
HoleNode
Branded type for Hole non-terminal
HoleToken
Branded type for Hole terminal
IdentConstructor
IdentConstructorBuilder
Use builder syntax to set the inputs and finish with build().
IdentNode
Branded type for Ident non-terminal
IdentToken
Branded type for Ident terminal
InfConstructor
InfConstructorBuilder
Use builder syntax to set the inputs and finish with build().
InfNode
Branded type for Inf non-terminal
InfToken
Branded type for Inf terminal
InlineCode1Constructor
InlineCode1ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
InlineCode1Node
Branded type for InlineCode1 non-terminal
InlineCode1Token
Branded type for InlineCode1 terminal
InlineCodeNode
Branded type for InlineCode non-terminal
IntegerConstructor
IntegerConstructorBuilder
Use builder syntax to set the inputs and finish with build().
IntegerNode
Branded type for Integer non-terminal
IntegerToken
Branded type for Integer terminal
KeyBaseNode
Branded type for KeyBase non-terminal
KeyConstructor
KeyConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeyIdentNode
Branded type for KeyIdent non-terminal
KeyNode
Branded type for Key non-terminal
KeyOptConstructor
KeyOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeyOptNode
Branded type for KeyOpt non-terminal
KeyTupleConstructor
KeyTupleConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeyTupleElementsConstructor
KeyTupleElementsConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeyTupleElementsNode
Branded type for KeyTupleElements non-terminal
KeyTupleElementsOptConstructor
KeyTupleElementsOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeyTupleElementsOptNode
Branded type for KeyTupleElementsOpt non-terminal
KeyTupleElementsTailConstructor
KeyTupleElementsTailConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeyTupleElementsTailNode
Branded type for KeyTupleElementsTail non-terminal
KeyTupleElementsTailOptConstructor
KeyTupleElementsTailOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeyTupleElementsTailOptNode
Branded type for KeyTupleElementsTailOpt non-terminal
KeyTupleNode
Branded type for KeyTuple non-terminal
KeyTupleOptConstructor
KeyTupleOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeyTupleOptNode
Branded type for KeyTupleOpt non-terminal
KeyValueNode
Branded type for KeyValue non-terminal
KeysConstructor
KeysConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeysListConstructor
KeysListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
KeysListNode
Branded type for KeysList non-terminal
KeysNode
Branded type for Keys non-terminal
LBraceToken
Branded type for LBrace terminal
LBracketToken
Branded type for LBracket terminal
LParenConstructor
LParenConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LParenNode
Branded type for LParen non-terminal
LParenToken
Branded type for LParen terminal
LitStr1Constructor
LitStr1ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr1EndConstructor
LitStr1EndConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr1EndNode
Branded type for LitStr1End non-terminal
LitStr1EndToken
Branded type for LitStr1End terminal
LitStr1ListConstructor
LitStr1ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr1ListGroupNode
Branded type for LitStr1ListGroup non-terminal
LitStr1ListNode
Branded type for LitStr1List non-terminal
LitStr1Node
Branded type for LitStr1 non-terminal
LitStr1StartConstructor
LitStr1StartConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr1StartNode
Branded type for LitStr1Start non-terminal
LitStr1StartToken
Branded type for LitStr1Start terminal
LitStr2Constructor
LitStr2ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr2EndConstructor
LitStr2EndConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr2EndNode
Branded type for LitStr2End non-terminal
LitStr2EndToken
Branded type for LitStr2End terminal
LitStr2ListConstructor
LitStr2ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr2ListGroupNode
Branded type for LitStr2ListGroup non-terminal
LitStr2ListNode
Branded type for LitStr2List non-terminal
LitStr2Node
Branded type for LitStr2 non-terminal
LitStr2StartConstructor
LitStr2StartConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr2StartNode
Branded type for LitStr2Start non-terminal
LitStr2StartToken
Branded type for LitStr2Start terminal
LitStr3Constructor
LitStr3ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr3EndConstructor
LitStr3EndConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr3EndNode
Branded type for LitStr3End non-terminal
LitStr3EndToken
Branded type for LitStr3End terminal
LitStr3ListConstructor
LitStr3ListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr3ListGroupNode
Branded type for LitStr3ListGroup non-terminal
LitStr3ListNode
Branded type for LitStr3List non-terminal
LitStr3Node
Branded type for LitStr3 non-terminal
LitStr3StartConstructor
LitStr3StartConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStr3StartNode
Branded type for LitStr3Start non-terminal
LitStr3StartToken
Branded type for LitStr3Start terminal
LitStrConstructor
LitStrConstructorBuilder
Use builder syntax to set the inputs and finish with build().
LitStrNode
Branded type for LitStr non-terminal
LitStrToken
Branded type for LitStr terminal
MapBindConstructor
MapBindConstructorBuilder
Use builder syntax to set the inputs and finish with build().
MapBindNode
Branded type for MapBind non-terminal
MapBindToken
Branded type for MapBind terminal
NaNConstructor
NaNConstructorBuilder
Use builder syntax to set the inputs and finish with build().
NaNNode
Branded type for NaN non-terminal
NaNToken
Branded type for NaN terminal
NoBacktickConstructor
NoBacktickConstructorBuilder
Use builder syntax to set the inputs and finish with build().
NoBacktickNode
Branded type for NoBacktick non-terminal
NoBacktickToken
Branded type for NoBacktick terminal
NoSQuoteConstructor
NoSQuoteConstructorBuilder
Use builder syntax to set the inputs and finish with build().
NoSQuoteNode
Branded type for NoSQuote non-terminal
NoSQuoteToken
Branded type for NoSQuote terminal
NullConstructor
NullConstructorBuilder
Use builder syntax to set the inputs and finish with build().
NullNode
Branded type for Null non-terminal
NullToken
Branded type for Null terminal
NumberNode
Branded type for Number non-terminal
ObjectConstructor
ObjectConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ObjectListConstructor
ObjectListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ObjectListNode
Branded type for ObjectList non-terminal
ObjectNode
Branded type for Object non-terminal
ObjectOpt0Constructor
ObjectOpt0ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ObjectOpt0Node
Branded type for ObjectOpt0 non-terminal
ObjectOpt1Constructor
ObjectOpt1ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ObjectOpt1Node
Branded type for ObjectOpt1 non-terminal
ObjectOptConstructor
ObjectOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ObjectOptNode
Branded type for ObjectOpt non-terminal
RBraceToken
Branded type for RBrace terminal
RBracketToken
Branded type for RBracket terminal
RParenConstructor
RParenConstructorBuilder
Use builder syntax to set the inputs and finish with build().
RParenNode
Branded type for RParen non-terminal
RParenToken
Branded type for RParen terminal
RootBindingNode
Branded type for RootBinding non-terminal
RootConstructor
RootConstructorBuilder
Use builder syntax to set the inputs and finish with build().
RootNode
Branded type for Root non-terminal
SQuoteConstructor
SQuoteConstructorBuilder
Use builder syntax to set the inputs and finish with build().
SQuoteNode
Branded type for SQuote non-terminal
SQuoteToken
Branded type for SQuote terminal
SectionBindingConstructor
SectionBindingConstructorBuilder
Use builder syntax to set the inputs and finish with build().
SectionBindingNode
Branded type for SectionBinding non-terminal
SectionBodyListConstructor
SectionBodyListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
SectionBodyListNode
Branded type for SectionBodyList non-terminal
SectionBodyNode
Branded type for SectionBody non-terminal
SectionBodyOptConstructor
SectionBodyOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
SectionBodyOptNode
Branded type for SectionBodyOpt non-terminal
SectionConstructor
SectionConstructorBuilder
Use builder syntax to set the inputs and finish with build().
SectionNode
Branded type for Section non-terminal
StrConstructor
StrConstructorBuilder
Use builder syntax to set the inputs and finish with build().
StrNode
Branded type for Str non-terminal
StrToken
Branded type for Str terminal
StringNode
Branded type for String non-terminal
StringsConstructor
StringsConstructorBuilder
Use builder syntax to set the inputs and finish with build().
StringsListConstructor
StringsListConstructorBuilder
Use builder syntax to set the inputs and finish with build().
StringsListNode
Branded type for StringsList non-terminal
StringsNode
Branded type for Strings non-terminal
TextBindingConstructor
TextBindingConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TextBindingNode
Branded type for TextBinding non-terminal
TextBindingOpt0Constructor
TextBindingOpt0ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TextBindingOpt0Node
Branded type for TextBindingOpt0 non-terminal
TextBindingOpt1Constructor
TextBindingOpt1ConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TextBindingOpt1Node
Branded type for TextBindingOpt1 non-terminal
TextBindingOptConstructor
TextBindingOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TextBindingOptNode
Branded type for TextBindingOpt non-terminal
TextConstructor
TextConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TextNode
Branded type for Text non-terminal
TextStartConstructor
TextStartConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TextStartNode
Branded type for TextStart non-terminal
TextStartToken
Branded type for TextStart terminal
TextToken
Branded type for Text terminal
TrueConstructor
TrueConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TrueNode
Branded type for True non-terminal
TrueToken
Branded type for True terminal
TupleConstructor
TupleConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TupleElementsConstructor
TupleElementsConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TupleElementsNode
Branded type for TupleElements non-terminal
TupleElementsOptConstructor
TupleElementsOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TupleElementsOptNode
Branded type for TupleElementsOpt non-terminal
TupleElementsTailConstructor
TupleElementsTailConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TupleElementsTailNode
Branded type for TupleElementsTail non-terminal
TupleElementsTailOptConstructor
TupleElementsTailOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TupleElementsTailOptNode
Branded type for TupleElementsTailOpt non-terminal
TupleIndexConstructor
TupleIndexConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TupleIndexNode
Branded type for TupleIndex non-terminal
TupleNode
Branded type for Tuple non-terminal
TupleOptConstructor
TupleOptConstructorBuilder
Use builder syntax to set the inputs and finish with build().
TupleOptNode
Branded type for TupleOpt non-terminal
ValueBindingConstructor
ValueBindingConstructorBuilder
Use builder syntax to set the inputs and finish with build().
ValueBindingNode
Branded type for ValueBinding non-terminal
ValueNode
Branded type for Value non-terminal
WsConstructor
WsConstructorBuilder
Use builder syntax to set the inputs and finish with build().
WsNode
Branded type for Ws non-terminal
WsToken
Branded type for Ws terminal

Enums

BindingRhsConstructor
BooleanConstructor
CodeBlock3ListGroupConstructor
CodeBlock4ListGroupConstructor
CodeBlock5ListGroupConstructor
CodeBlock6ListGroupConstructor
CodeBlockConstructor
DelimCode1ListGroupConstructor
DelimCode2ListGroupConstructor
DelimCode3ListGroupConstructor
DelimCodeConstructor
InlineCodeConstructor
KeyBaseConstructor
KeyIdentConstructor
KeyValueConstructor
LitStr1ListGroupConstructor
LitStr2ListGroupConstructor
LitStr3ListGroupConstructor
NumberConstructor
RootBindingConstructor
SectionBodyConstructor
StringConstructor
ValueConstructor