Module tree

Module tree 

Structs

CharInfo
Information about a character position in text
ConcreteSyntaxTree
A generic concrete syntax tree with stable child ordering
CstNodeId
DynamicTokenId
A dynamic token id that provided by the user land.
InputSpan
A span that is only valid within the context of the input text.
LineNumbers
A helper struct that stores the new line indexes of the input text. This is used to get the line number of a given span.
UnexpectedNode

Enums

CstNodeData
NonTerminalData
TerminalData
ViewConstructionError
Error that occurs when constructing a view from a NonTerminalHandle.

Traits

CstFacade
NonTerminalHandle
A trait that all generated non-terminal handles implements.
RecursiveView
A trait that generated recursive views implements.
TerminalHandle