ViewConstructionError

Enum ViewConstructionError 

pub enum ViewConstructionError<T, Nt, E = Infallible> {
    UnexpectedNode {
        node: CstNodeId,
        data: CstNodeData<T, Nt>,
        expected_kind: NodeKind<T, Nt>,
    },
    UnexpectedExtraNode {
        node: CstNodeId,
    },
    UnexpectedEndOfChildren {
        parent: CstNodeId,
    },
    UnexpectedEmptyChildren {
        node: CstNodeId,
    },
    NodeIdNotFound {
        node: CstNodeId,
    },
    Error(E),
}
Error that occurs when constructing a view from a NonTerminalHandle.

Variants



UnexpectedNode

Expected a specific kind of terminal node, but got an invalid node

Fields

node: CstNodeId

The index of the node.

data: CstNodeData<T, Nt>

The data of the node.

expected_kind: NodeKind<T, Nt>

The expected kind.



UnexpectedExtraNode

Expected an extra node, but got an invalid node

Fields

node: CstNodeId

The index of the node.



UnexpectedEndOfChildren

Unexpected end of children

Fields

parent: CstNodeId

The index of the node.



UnexpectedEmptyChildren

Unexpected empty children for a non-terminal

Fields

node: CstNodeId

The index of the node.



NodeIdNotFound

The node ID not found in the tree

Fields

node: CstNodeId

The index of the node.



Error(E)

Error that occurs when constructing a view from a NonTerminalHandle.

Implementations

Source

impl<T, Nt, E> ViewConstructionError<T, Nt, E>

Source

impl<T, Nt> ViewConstructionError<T, Nt, Infallible>

pub fn into_any_error<E>(self) -> ViewConstructionError<T, Nt, E>

Source

impl<T, Nt> ViewConstructionError<T, Nt, Infallible>
where T: Copy, Nt: Copy,