ConcreteSyntaxTree

Struct ConcreteSyntaxTree 

pub struct ConcreteSyntaxTree<T, Nt> { /* private fields */ }
A generic concrete syntax tree with stable child ordering

Implementations

Source

impl<T, Nt> ConcreteSyntaxTree<T, Nt>
where T: Clone, Nt: Clone,

pub fn new(root_data: CstNodeData<T, Nt>) -> Self

pub fn root(&self) -> CstNodeId

pub fn set_root(&mut self, new_root: CstNodeId)

pub fn change_parent(&mut self, id: CstNodeId, new_parent: CstNodeId)

pub fn add_node(&mut self, data: CstNodeData<T, Nt>) -> CstNodeId

pub fn add_node_with_parent( &mut self, data: CstNodeData<T, Nt>, parent: CstNodeId, ) -> CstNodeId

pub fn add_child(&mut self, parent: CstNodeId, child: CstNodeId)

pub fn has_no_children(&self, node: CstNodeId) -> bool

pub fn children( &self, node: CstNodeId, ) -> impl DoubleEndedIterator<Item = CstNodeId> + '_

pub fn parent(&self, node: CstNodeId) -> Option<CstNodeId>

pub fn get_str<'a: 'c, 'b: 'c, 'c>( &'a self, terminal: TerminalData, input: &'b str, ) -> Option<&'c str>

pub fn dynamic_token(&self, id: DynamicTokenId) -> Option<&str>

pub fn update_node( &mut self, id: CstNodeId, data: CstNodeData<T, Nt>, ) -> Option<CstNodeData<T, Nt>>

pub fn update_children( &mut self, id: CstNodeId, new_children: impl IntoIterator<Item = CstNodeId>, )

pub fn insert_dynamic_terminal( &mut self, data: impl Into<String>, ) -> DynamicTokenId

Source

impl<T, Nt> ConcreteSyntaxTree<T, Nt>
where T: Copy, Nt: Copy,

pub fn node_data(&self, node: CstNodeId) -> Option<CstNodeData<T, Nt>>

pub fn remove_node(&mut self, id: CstNodeId)

Remove a node from the tree by removing it from all parent-child relationships. The node data remains in the vector but becomes unreachable through tree traversal.

Source

impl ConcreteSyntaxTree<TerminalKind, NonTerminalKind>

pub fn get_non_terminal( &self, id: CstNodeId, kind: NonTerminalKind, ) -> Result<NonTerminalData, CstConstructError>

pub fn get_terminal( &self, id: CstNodeId, kind: TerminalKind, ) -> Result<TerminalData, CstConstructError>

pub fn collect_nodes<'v, const N: usize, V: BuiltinTerminalVisitor<E, F>, O, E, F: CstFacade>( &self, facade: &F, parent: CstNodeId, nodes: [NodeKind<TerminalKind, NonTerminalKind>; N], visitor: impl FnMut([CstNodeId; N], &'v mut V) -> Result<(O, &'v mut V), CstConstructError<E>>, visit_ignored: &'v mut V, ) -> Result<O, CstConstructError<E>>

pub fn root_handle(&self) -> RootHandle

pub fn visit_from_root<V: CstVisitor<Self>>( &self, visitor: &mut V, ) -> Result<(), V::Error>