pub struct LineNumbers<'a> { /* private fields */ }Expand description
A helper struct that stores the new line indexes of the input text. This is used to get the line number of a given span.
Implementations
Sourceimpl LineNumbers<'_>
impl LineNumbers<'_>