This file was generated by eure-gen.
Do not edit manually.
Modules
Structs
- Array
Begin Constructor - Array
Begin Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
Begin Node - Branded type for ArrayBegin non-terminal
- Array
Constructor - Array
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
Elements Constructor - Array
Elements Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
Elements Node - Branded type for ArrayElements non-terminal
- Array
Elements OptConstructor - Array
Elements OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
Elements OptNode - Branded type for ArrayElementsOpt non-terminal
- Array
Elements Tail Constructor - Array
Elements Tail Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
Elements Tail Node - Branded type for ArrayElementsTail non-terminal
- Array
Elements Tail OptConstructor - Array
Elements Tail OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
Elements Tail OptNode - Branded type for ArrayElementsTailOpt non-terminal
- Array
EndConstructor - Array
EndConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
EndNode - Branded type for ArrayEnd non-terminal
- Array
Marker Constructor - Array
Marker Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
Marker Node - Branded type for ArrayMarker non-terminal
- Array
Marker OptConstructor - Array
Marker OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
Marker OptNode - Branded type for ArrayMarkerOpt non-terminal
- Array
Node - Branded type for Array non-terminal
- Array
OptConstructor - Array
OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Array
OptNode - Branded type for ArrayOpt non-terminal
- AtConstructor
- AtConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - AtNode
- Branded type for At non-terminal
- AtToken
- Branded type for At terminal
- Backtick1
Constructor - Backtick1
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Backtick1
Node - Branded type for Backtick1 non-terminal
- Backtick1
Token - Branded type for Backtick1 terminal
- Backtick2
Constructor - Backtick2
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Backtick2
Node - Branded type for Backtick2 non-terminal
- Backtick2
Token - Branded type for Backtick2 terminal
- Backtick3
Constructor - Backtick3
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Backtick3
Node - Branded type for Backtick3 non-terminal
- Backtick3
Token - Branded type for Backtick3 terminal
- Backtick4
Constructor - Backtick4
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Backtick4
Node - Branded type for Backtick4 non-terminal
- Backtick4
Token - Branded type for Backtick4 terminal
- Backtick5
Constructor - Backtick5
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Backtick5
Node - Branded type for Backtick5 non-terminal
- Backtick5
Token - Branded type for Backtick5 terminal
- Begin
Constructor - Begin
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Begin
Node - Branded type for Begin non-terminal
- Bind
Constructor - Bind
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Bind
Node - Branded type for Bind non-terminal
- Bind
Token - Branded type for Bind terminal
- Binding
Constructor - Binding
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Binding
Node - Branded type for Binding non-terminal
- Binding
RhsNode - Branded type for BindingRhs non-terminal
- Boolean
Node - Branded type for Boolean non-terminal
- Code
Block3 Constructor - Code
Block3 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block3 List Constructor - Code
Block3 List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block3 List Group Node - Branded type for CodeBlock3ListGroup non-terminal
- Code
Block3 List Node - Branded type for CodeBlock3List non-terminal
- Code
Block3 Node - Branded type for CodeBlock3 non-terminal
- Code
Block4 Constructor - Code
Block4 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block4 List Constructor - Code
Block4 List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block4 List Group Node - Branded type for CodeBlock4ListGroup non-terminal
- Code
Block4 List Node - Branded type for CodeBlock4List non-terminal
- Code
Block4 Node - Branded type for CodeBlock4 non-terminal
- Code
Block5 Constructor - Code
Block5 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block5 List Constructor - Code
Block5 List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block5 List Group Node - Branded type for CodeBlock5ListGroup non-terminal
- Code
Block5 List Node - Branded type for CodeBlock5List non-terminal
- Code
Block5 Node - Branded type for CodeBlock5 non-terminal
- Code
Block6 Constructor - Code
Block6 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block6 List Constructor - Code
Block6 List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block6 List Group Node - Branded type for CodeBlock6ListGroup non-terminal
- Code
Block6 List Node - Branded type for CodeBlock6List non-terminal
- Code
Block6 Node - Branded type for CodeBlock6 non-terminal
- Code
Block End3 Constructor - Code
Block End3 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block End3 Node - Branded type for CodeBlockEnd3 non-terminal
- Code
Block End3 Token - Branded type for CodeBlockEnd3 terminal
- Code
Block End4 Constructor - Code
Block End4 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block End4 Node - Branded type for CodeBlockEnd4 non-terminal
- Code
Block End4 Token - Branded type for CodeBlockEnd4 terminal
- Code
Block End5 Constructor - Code
Block End5 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block End5 Node - Branded type for CodeBlockEnd5 non-terminal
- Code
Block End5 Token - Branded type for CodeBlockEnd5 terminal
- Code
Block End6 Constructor - Code
Block End6 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block End6 Node - Branded type for CodeBlockEnd6 non-terminal
- Code
Block End6 Token - Branded type for CodeBlockEnd6 terminal
- Code
Block Node - Branded type for CodeBlock non-terminal
- Code
Block Start3 Constructor - Code
Block Start3 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block Start3 Node - Branded type for CodeBlockStart3 non-terminal
- Code
Block Start3 Token - Branded type for CodeBlockStart3 terminal
- Code
Block Start4 Constructor - Code
Block Start4 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block Start4 Node - Branded type for CodeBlockStart4 non-terminal
- Code
Block Start4 Token - Branded type for CodeBlockStart4 terminal
- Code
Block Start5 Constructor - Code
Block Start5 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block Start5 Node - Branded type for CodeBlockStart5 non-terminal
- Code
Block Start5 Token - Branded type for CodeBlockStart5 terminal
- Code
Block Start6 Constructor - Code
Block Start6 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Code
Block Start6 Node - Branded type for CodeBlockStart6 non-terminal
- Code
Block Start6 Token - Branded type for CodeBlockStart6 terminal
- Comma
Constructor - Comma
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Comma
Node - Branded type for Comma non-terminal
- Comma
Token - Branded type for Comma terminal
- Continue
Constructor - Continue
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Continue
Node - Branded type for Continue non-terminal
- Dollar
Token - Branded type for Dollar terminal
- DotConstructor
- DotConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - DotNode
- Branded type for Dot non-terminal
- DotToken
- Branded type for Dot terminal
- EndConstructor
- EndConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - EndNode
- Branded type for End non-terminal
- EscToken
- Branded type for Esc terminal
- Eure
Bindings Constructor - Eure
Bindings Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Eure
Bindings Node - Branded type for EureBindings non-terminal
- Eure
Constructor - Eure
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Eure
Node - Branded type for Eure non-terminal
- Eure
OptConstructor - Eure
OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Eure
OptNode - Branded type for EureOpt non-terminal
- Eure
Sections Constructor - Eure
Sections Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Eure
Sections Node - Branded type for EureSections non-terminal
- ExtConstructor
- ExtConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - ExtNode
- Branded type for Ext non-terminal
- Extension
Name Space Constructor - Extension
Name Space Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Extension
Name Space Node - Branded type for ExtensionNameSpace non-terminal
- False
Constructor - False
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - False
Node - Branded type for False non-terminal
- False
Token - Branded type for False terminal
- Float
Constructor - Float
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Float
Node - Branded type for Float non-terminal
- Float
Token - Branded type for Float terminal
- Grammar
Newline Constructor - Grammar
Newline Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Grammar
Newline Node - Branded type for GrammarNewline non-terminal
- Grammar
Newline Token - Branded type for GrammarNewline terminal
- Hash
Token - Branded type for Hash terminal
- Hole
Constructor - Hole
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Hole
Node - Branded type for Hole non-terminal
- Hole
Token - Branded type for Hole terminal
- Ident
Constructor - Ident
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Ident
Node - Branded type for Ident non-terminal
- Ident
Token - Branded type for Ident terminal
- InfConstructor
- InfConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - InfNode
- Branded type for Inf non-terminal
- InfToken
- Branded type for Inf terminal
- Inline
Code1 Constructor - Inline
Code1 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Inline
Code1 Node - Branded type for InlineCode1 non-terminal
- Inline
Code1 Token - Branded type for InlineCode1 terminal
- Inline
Code2 Constructor - Inline
Code2 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Inline
Code2 List Constructor - Inline
Code2 List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Inline
Code2 List Group Node - Branded type for InlineCode2ListGroup non-terminal
- Inline
Code2 List Node - Branded type for InlineCode2List non-terminal
- Inline
Code2 Node - Branded type for InlineCode2 non-terminal
- Inline
Code End2 Constructor - Inline
Code End2 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Inline
Code End2 Node - Branded type for InlineCodeEnd2 non-terminal
- Inline
Code End2 Token - Branded type for InlineCodeEnd2 terminal
- Inline
Code Node - Branded type for InlineCode non-terminal
- Inline
Code Start2 Constructor - Inline
Code Start2 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Inline
Code Start2 Node - Branded type for InlineCodeStart2 non-terminal
- Inline
Code Start2 Token - Branded type for InlineCodeStart2 terminal
- Integer
Constructor - Integer
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Integer
Node - Branded type for Integer non-terminal
- Integer
Token - Branded type for Integer terminal
- KeyBase
Node - Branded type for KeyBase non-terminal
- KeyConstructor
- KeyConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - KeyIdent
Node - Branded type for KeyIdent non-terminal
- KeyNode
- Branded type for Key non-terminal
- KeyOpt
Constructor - KeyOpt
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - KeyOpt
Node - Branded type for KeyOpt non-terminal
- KeyTuple
Constructor - KeyTuple
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - KeyTuple
Elements Constructor - KeyTuple
Elements Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - KeyTuple
Elements Node - Branded type for KeyTupleElements non-terminal
- KeyTuple
Elements OptConstructor - KeyTuple
Elements OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - KeyTuple
Elements OptNode - Branded type for KeyTupleElementsOpt non-terminal
- KeyTuple
Elements Tail Constructor - KeyTuple
Elements Tail Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - KeyTuple
Elements Tail Node - Branded type for KeyTupleElementsTail non-terminal
- KeyTuple
Elements Tail OptConstructor - KeyTuple
Elements Tail OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - KeyTuple
Elements Tail OptNode - Branded type for KeyTupleElementsTailOpt non-terminal
- KeyTuple
Node - Branded type for KeyTuple non-terminal
- KeyTuple
OptConstructor - KeyTuple
OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - KeyTuple
OptNode - Branded type for KeyTupleOpt non-terminal
- KeyValue
Node - Branded type for KeyValue non-terminal
- Keys
Constructor - Keys
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Keys
List Constructor - Keys
List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Keys
List Node - Branded type for KeysList non-terminal
- Keys
Node - Branded type for Keys non-terminal
- LBrace
Token - Branded type for LBrace terminal
- LBracket
Token - Branded type for LBracket terminal
- LParen
Constructor - LParen
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - LParen
Node - Branded type for LParen non-terminal
- LParen
Token - Branded type for LParen terminal
- MapBind
Constructor - MapBind
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - MapBind
Node - Branded type for MapBind non-terminal
- MapBind
Token - Branded type for MapBind terminal
- NaNConstructor
- NaNConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - NaNNode
- Branded type for NaN non-terminal
- NaNToken
- Branded type for NaN terminal
- NoBacktick
Constructor - NoBacktick
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - NoBacktick
Inline Constructor - NoBacktick
Inline Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - NoBacktick
Inline Node - Branded type for NoBacktickInline non-terminal
- NoBacktick
Inline Token - Branded type for NoBacktickInline terminal
- NoBacktick
Node - Branded type for NoBacktick non-terminal
- NoBacktick
Token - Branded type for NoBacktick terminal
- Null
Constructor - Null
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Null
Node - Branded type for Null non-terminal
- Null
Token - Branded type for Null terminal
- Number
Node - Branded type for Number non-terminal
- Object
Constructor - Object
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Object
List Constructor - Object
List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Object
List Node - Branded type for ObjectList non-terminal
- Object
Node - Branded type for Object non-terminal
- Object
Opt0 Constructor - Object
Opt0 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Object
Opt0 Node - Branded type for ObjectOpt0 non-terminal
- Object
Opt1 Constructor - Object
Opt1 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Object
Opt1 Node - Branded type for ObjectOpt1 non-terminal
- Object
OptConstructor - Object
OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Object
OptNode - Branded type for ObjectOpt non-terminal
- RBrace
Token - Branded type for RBrace terminal
- RBracket
Token - Branded type for RBracket terminal
- RParen
Constructor - RParen
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - RParen
Node - Branded type for RParen non-terminal
- RParen
Token - Branded type for RParen terminal
- Root
Constructor - Root
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Root
Node - Branded type for Root non-terminal
- Section
Binding Constructor - Section
Binding Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Section
Binding Node - Branded type for SectionBinding non-terminal
- Section
Body List Constructor - Section
Body List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Section
Body List Node - Branded type for SectionBodyList non-terminal
- Section
Body Node - Branded type for SectionBody non-terminal
- Section
Body OptConstructor - Section
Body OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Section
Body OptNode - Branded type for SectionBodyOpt non-terminal
- Section
Constructor - Section
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Section
Node - Branded type for Section non-terminal
- StrConstructor
- StrConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - StrNode
- Branded type for Str non-terminal
- StrToken
- Branded type for Str terminal
- Strings
Constructor - Strings
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Strings
List Constructor - Strings
List Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Strings
List Node - Branded type for StringsList non-terminal
- Strings
Node - Branded type for Strings non-terminal
- Text
Binding Constructor - Text
Binding Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Text
Binding Node - Branded type for TextBinding non-terminal
- Text
Binding Opt0 Constructor - Text
Binding Opt0 Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Text
Binding Opt0 Node - Branded type for TextBindingOpt0 non-terminal
- Text
Binding OptConstructor - Text
Binding OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Text
Binding OptNode - Branded type for TextBindingOpt non-terminal
- Text
Constructor - Text
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Text
Node - Branded type for Text non-terminal
- Text
Start Constructor - Text
Start Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Text
Start Node - Branded type for TextStart non-terminal
- Text
Start Token - Branded type for TextStart terminal
- Text
Token - Branded type for Text terminal
- True
Constructor - True
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - True
Node - Branded type for True non-terminal
- True
Token - Branded type for True terminal
- Tuple
Constructor - Tuple
Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Tuple
Elements Constructor - Tuple
Elements Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Tuple
Elements Node - Branded type for TupleElements non-terminal
- Tuple
Elements OptConstructor - Tuple
Elements OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Tuple
Elements OptNode - Branded type for TupleElementsOpt non-terminal
- Tuple
Elements Tail Constructor - Tuple
Elements Tail Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Tuple
Elements Tail Node - Branded type for TupleElementsTail non-terminal
- Tuple
Elements Tail OptConstructor - Tuple
Elements Tail OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Tuple
Elements Tail OptNode - Branded type for TupleElementsTailOpt non-terminal
- Tuple
Index Constructor - Tuple
Index Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Tuple
Index Node - Branded type for TupleIndex non-terminal
- Tuple
Node - Branded type for Tuple non-terminal
- Tuple
OptConstructor - Tuple
OptConstructor Builder - Use builder syntax to set the inputs and finish with
build(). - Tuple
OptNode - Branded type for TupleOpt non-terminal
- Value
Binding Constructor - Value
Binding Constructor Builder - Use builder syntax to set the inputs and finish with
build(). - Value
Binding Node - Branded type for ValueBinding non-terminal
- Value
Node - Branded type for Value non-terminal
- WsConstructor
- WsConstructor
Builder - Use builder syntax to set the inputs and finish with
build(). - WsNode
- Branded type for Ws non-terminal
- WsToken
- Branded type for Ws terminal
Enums
- Binding
RhsConstructor - Boolean
Constructor - Code
Block3 List Group Constructor - Code
Block4 List Group Constructor - Code
Block5 List Group Constructor - Code
Block6 List Group Constructor - Code
Block Constructor - Inline
Code2 List Group Constructor - Inline
Code Constructor - KeyBase
Constructor - KeyIdent
Constructor - KeyValue
Constructor - Number
Constructor - Section
Body Constructor - Value
Constructor