Structs
- Char
Info - Information about a character position in text
- Concrete
Syntax Tree - A generic concrete syntax tree with stable child ordering
- CstNode
Id - Dynamic
Token Id - A dynamic token id that provided by the user land.
- Input
Span - A span that is only valid within the context of the input text.
- Line
Numbers - A helper struct that stores the new line indexes of the input text. This is used to get the line number of a given span.
- Unexpected
Node
Enums
- CstNode
Data - NonTerminal
Data - Terminal
Data - View
Construction Error - Error that occurs when constructing a view from a NonTerminalHandle.
Traits
- CstFacade
- NonTerminal
Handle - A trait that all generated non-terminal handles implements.
- Recursive
View - A trait that generated recursive views implements.
- Terminal
Handle