pub enum ViewConstructionError<T, Nt, E = Infallible> {
UnexpectedNode {
node: CstNodeId,
data: CstNodeData<T, Nt>,
expected_kind: NodeKind<T, Nt>,
},
UnexpectedExtraNode {
node: CstNodeId,
},
UnexpectedEndOfChildren {
parent: CstNodeId,
},
UnexpectedEmptyChildren {
node: CstNodeId,
},
NodeIdNotFound {
node: CstNodeId,
},
Error(E),
}Expand description
Error that occurs when constructing a view from a NonTerminalHandle.
Variants
UnexpectedNode
Expected a specific kind of terminal node, but got an invalid node
Fields

data: CstNodeData<T, Nt>The data of the node.
UnexpectedExtraNode
Expected an extra node, but got an invalid node
UnexpectedEndOfChildren
Unexpected end of children
UnexpectedEmptyChildren
Unexpected empty children for a non-terminal
NodeIdNotFound
The node ID not found in the tree
Error(E)
Error that occurs when constructing a view from a NonTerminalHandle.
Implementations
Sourceimpl<T, Nt, E> ViewConstructionError<T, Nt, E>
impl<T, Nt, E> ViewConstructionError<T, Nt, E>
pub fn extract_error( self, ) -> Result<E, ViewConstructionError<T, Nt, Infallible>>
Sourceimpl<T, Nt> ViewConstructionError<T, Nt, Infallible>
impl<T, Nt> ViewConstructionError<T, Nt, Infallible>
pub fn into_any_error<E>(self) -> ViewConstructionError<T, Nt, E>
Sourceimpl<T, Nt> ViewConstructionError<T, Nt, Infallible>
impl<T, Nt> ViewConstructionError<T, Nt, Infallible>
pub fn unexpected_node(&self) -> Option<UnexpectedNode<T, Nt>>